<?php

/**
 * @desc 	  MoodlePayments  - Pay for a course enrolment
 * @since 	  1.8
 * @version	  1.3
 * @author	  Luuk Verhoeven [luuk@sebsoft.nl] / Sebastian Berm [sebastian@sebsoft.nl]
 * @package    enrol/mpay
 * @copyright  Sebsoft.nl
 */
class Mpay
{

    static private $holdRedirect = false;
    static public $popup = '';

    /**
     * @desc Enrol user into course via enrol instance.
     * @param stdClass $instance
     * @param int $userid
     * @param int $roleid optional role id
     * @param int $timestart 0 means unknown
     * @param int $timeend 0 means forever
     * @param int $status default to ENROL_USER_ACTIVE for new enrolments, no change by default in updates
     * @return void
     */
    static public function enrol_user(stdClass $instance, $userid, $roleid = NULL, $timestart = 0, $timeend = 0, $status = NULL)
    {
        global $DB, $USER, $CFG; // CFG necessary!!!

        if ($instance->courseid == SITEID)
        {
            throw new coding_exception('invalid attempt to enrol into frontpage course!');
        }
        $name = 'mpay';
        $courseid = $instance->courseid;

        if ($instance->enrol !== $name)
        {
            throw new coding_exception('invalid enrol instance!');
        }
        $context = context_course::instance($instance->courseid,MUST_EXIST);

        $inserted = false;
        if ($ue = $DB->get_record('user_enrolments', array('enrolid' => $instance->id, 'userid' => $userid)))
        {
            //only update if timestart or timeend or status are different.
            if ($ue->timestart != $timestart or $ue->timeend != $timeend or (!is_null($status) and $ue->status != $status))
            {
                $ue->timestart = $timestart;
                $ue->timeend = $timeend;
                if (!is_null($status))
                {
                    $ue->status = $status;
                }
                $ue->modifierid = $USER->id;
                $ue->timemodified = time();
                $DB->update_record('user_enrolments', $ue);
            }
        }
        else
        {
            $ue = new stdClass();
            $ue->enrolid = $instance->id;
            $ue->status = is_null($status) ? ENROL_USER_ACTIVE : $status;
            $ue->userid = $userid;
            $ue->timestart = $timestart;
            $ue->timeend = $timeend;
            $ue->modifierid = $USER->id;
            $ue->timecreated = time();
            $ue->timemodified = $ue->timecreated;
            $ue->id = $DB->insert_record('user_enrolments', $ue);

            $inserted = true;
        }

        if ($roleid)
        {
            role_assign($roleid, $userid, $context->id, 'enrol_' . $name, $instance->id);
        }

        if ($inserted)
        {
            // add extra info and trigger event
            $ue->courseid = $courseid;
            $ue->enrol = $name;
            events_trigger('user_enrolled', $ue);
        }

        // reset primitive require_login() caching
        if ($userid == $USER->id)
        {
            if (isset($USER->enrol['enrolled'][$courseid]))
            {
                unset($USER->enrol['enrolled'][$courseid]);
            }
            if (isset($USER->enrol['tempguest'][$courseid]))
            {
                unset($USER->enrol['tempguest'][$courseid]);
                $USER->access = remove_temp_roles($context, $USER->access);
            }
        }
        return $inserted;
    }

    static public function getEnrolSettings($courseid, $enrol='mpay')
    {
        global $DB;
        if ($result = $DB->get_record('enrol', array('enrol' => $enrol, 'courseid' => $courseid)))
        {
            return $result;
        }
        else
        {
            return false;
        }
    }

    /**
     *
     * @desc Validation for a coupon code. <br> <p style="color:red">Use course id or enrol id or both</p>
     *
     * @param string $code
     * @param int $enrolid
     * @param int $courseid
     * @return object or false
     */
    static public function validateCoupon($code='', $enrolid=0, $courseid=0)
    {
        global $DB;
        $return = false;
        //get db records
        if ($code != '' && $courseid != 0)
        {
            if ($result = $DB->get_record('enrol_mpay_couponcode', array('course_id' => $courseid, 'code' => $code)))
            {
                $return = $result;
            }
        }
        elseif ($enrolid != 0)
        {
            if ($result = $DB->get_record('enrol_mpay_couponcode', array('enrol_id' => $enrolid)))
            {
                $return = $result;
            }
        }
        elseif ($courseid != 0)
        {
            if ($result = $DB->get_records('enrol_mpay_couponcode', array('course_id' => $courseid)))
            {
                $return = $result;
            }
        }
        return $return;
    }

    /**
     * @desc Get all paymentmethods
     * @param boolean $trans
     * @return array $array Or false
     */
    static public function getPaymentMethods($trans = false)
    {
        global $DB;

        if ($methods = $DB->get_records('enrol_mpay_methods', array(), 'method_id DESC'))
        {
            $array = array();

            foreach ($methods as $method)
            {
                $name = ($trans) ? self::getStringmPayRT($method->systemname, 'enrol_mpay') : $method->systemname;
                $array[$method->systemname] = $name;
            }
            return $array;
        }
        else
        {
            return false;
        }
    }

    static public function show_payment_method($method, $isdefault=false, $morechoices=true, &$extra, &$realtext)
    {
        global $CFG, $DB;

        if (strtolower($method->systemname) == 'ideal')
        {
            if (!$isdefault || $morechoices)
            {
                $extra.= "<div style='display:none;overflow:hidden;' id='idealbankchoice'>";
                $extra.= "<div class='fitem'>
                                    <div class='fitemtitle' style='text-align:left;'><h4>" . get_string('ideal', 'enrol_mpay') . "</h4></div>
                                    <div class='felement'>
                                            <img src='" . $CFG->wwwroot . "/enrol/mpay/pix/ideallogosml.jpg' alt='iDeal'  />
                                    </div>
                            </div>";
            }
            else
            {
                $extra.= "<div id='idealbankchoice'>";
                $extra.= "<div class='fitem'>
                                    <div class='fitemtitle' style='text-align:left;'><h4>" . get_string('ideal', 'enrol_mpay') . "</h4></div>
                                    <div class='felement'>
                                            <img src='" . $CFG->wwwroot . "/enrol/mpay/pix/ideallogosml.jpg' alt='iDeal'  />
                                    </div>
                            </div>";
            }

            $issuers = $DB->get_records('enrol_mpay_idealbank'); # Order by id would do, but that's ehm, default now :)
            foreach ($issuers as $issuer)
            {
                $image = "";

                if (strlen($issuer->imgurl) > 5) # If url is set, show image instead of bank name
                {
                    $image = "<img src='" . $issuer->imgurl . "' alt='" . $issuer->name . "' />";
                }
                else
                {
                    $image = $issuer->name;
                }

                $extra.= "<div class='fitem'>
							<div class='fitemtitle'></div>
							<div class='felement idealbankline' id='" . str_replace(' ', '', $issuer->name) . "'>
							<label>
								<input type='radio' name='issuer' value='" . $issuer->bankid . "'> " . $image . "
							</label>
							</div>
						</div>";
            }

            $extra.= "</div>";

            if ($morechoices)
            {
                if ($morechoices)
                {
                    $extra.= "<h4>" . get_string('choosedifferentpaymentmethod', 'enrol_mpay') . "</h4>";
                }
                $selected = ($isdefault) ? "checked='checked'" : "";
                $realtext.= "<div class='fitemtitle'></div><div class='felement'>";
                $realtext.= "<label class='pc_radiobutton'>
									<input type='radio' name='paymentmethod' value='" . $method->systemname . "' $selected />" . $method->name . "
							</label>";
                $realtext.= "</div>";
            }
            else
            {
                $realtext.= "<input type='hidden' name='paymentmethod' value='" . $method->systemname . "' />";
            }
        }
        else
        {
            if ($morechoices)
            {
                $selected = ($isdefault) ? "checked='checked'" : "";

                $realtext.= "<div class='paymentmethodline'>";
                $realtext.= "<label class='pc_radiobutton'><input type='radio' name='paymentmethod' value='" . $method->systemname . "' $selected />" . self::getStringmPayRT($method->systemname) . "</label>";
                $realtext.= "</div>";
            }
            else
            {
                $realtext.= "<input type='hidden' name='paymentmethod' value='" . $method->systemname . "' />";
            }
        }

        return true;
    }

    /**
     * @desc getAvailableCoupon <p>Gives you array with object and avialablecoupons</p>
     * @param int $courseId
     * @return Array with objects or false
     */
    static public function getAvailableCoupon($courseId)
    {
        global $DB;
        $now = strtotime(date('Y-m-d', time()));
        $tmpArray = array();
        $sql = 'SELECT * FROM {enrol_mpay_couponcode} WHERE courseid="' . intval($courseId) . '" OR courseid="0"';
        if ($results = $DB->get_records_sql($sql))
        {
            foreach ($results as $result)
            {
                //validation if a key is avialable
                $check = false;

                if ($now >= strtotime($result->validfrom))
                {
                    if (strtotime($result->validto) >= $now)
                    {
                        $check = true;
                    }
                }

                if ($check)
                {
                    $tmpArray[] = $result;
                }
            }
        }

        return!empty($tmpArray) ? $tmpArray : false;
    }

    static public function setPopup($courseid)
    {
        global $CFG;
        self::$popup = '<p><div id="couponcodePopup">
                                <div class="bd">
                                        <form method="POST" action="#">
                                                <strong>' . get_string('couponcode', 'enrol_mpay') . '</strong>
                                                <p>' . get_string('couponcode_desc', 'enrol_mpay') . '</p>
                                                <p id="couponcodeerror"></p>
                                                <input type="hidden" name="courseid" id="coursekey" value="' . $courseid . '"/>
                                                <input type="hidden" name="couponactionurl" id="actionurl" value="' . $CFG->wwwroot . '/enrol/mpay/couponcheck.php"/>
                                                <input type="text" name="code" value="" id="couponkey" />
                                                <input type="submit" name="check" value="'.get_string('activate','enrol_mpay').'" id="id_mpay_checkcoupon" />
                                        </form>
                                </div>
                        </div></p>';
    }

    static public function displayPopup()
    {
        return self::$popup;
    }

    static public function getmPayPaymentMethodList()
    {
        global $CFG, $DB;
        $list = array();
        $methods = $DB->get_records('enrol_mpay_methods', array(), 'method_id DESC');
        foreach ($methods as $method)
        {
            $name = 'enrol_mpay_payment_methode_' . $method->systemname;
            if (isset($CFG->$name))
            {
                if ($CFG->$name == 1)
                {
                    $list[$method->systemname] = $method;
                }
            }
        }
        return $list;
    }

    /**
     * Realtime getstring mapper
     *
     * Allows mPay to be 'updated' in real time, if needed...
     *
     * @param string $string
     * @return string
     */
    static public function getStringmPayRT($string)
    {
        global $DB;
        $val = get_string($string, 'enrol_mpay');

        if (strstr($val, '[['))
        {
            # Real time polling is enabled
            # If it's enabled, just get the lang file from the db
            # Otherwise, just remove the [[ and the ]]
            $var = $DB->get_record('enrol_mpay_trans', array('lang' => current_language(), 'code' => $string));
            if ($var !== false)
            {
                return $var['translation'];
            }
            # If we're still here... we just don't understand the translated value
            $val = substr($val, 2);
            $val = substr($val, (-strlen($val)), -2); # This should work
        }
        return $val;
    }

    static public function redirect($url, $message='', $delay=2)
    {
        if (!headers_sent($file, $line))
        {
            if (self::$holdRedirect == false)
            {
                redirect($url, $message, $delay);
            }
            else
            {
                echo 'Mpay.class.php holds redirects. this is a debug option.';
            }
        }
        else
        {
            echo 'Headers where sent Please fix this';
        }
    }
}