<?php
/// FUNCTIONS //////////////////////////////////////////////////////////////////


function email_mpay_error_to_admin($subject, $data) {
    $admin = get_admin();
    $site = get_site();

    $message = "$site->fullname:  Transaction failed.\n\n$subject\n\n";

    foreach ($data as $key => $value) {
        $message .= "$key => $value\n";
    }

    email_to_user($admin, $admin, "mPay ERROR: ".$subject, $message);

}

/// CLASSES //////////////////////////////////////////////////////////////////

class mpsupProcessor
{
    private $ixr;
    
    
    function __construct()
    {
        $this->ixr = null;
    }
    
	private function init_xmlrpc_connection()
	{
		global $CFG;
		# Only require if the class hasn't been setup right, otherwise it may interfere
		# with other products
		if (!class_exists('IXR_Client'))
		{
        	require_once($CFG->dirroot.'/enrol/mpay/class/IXR_Library.inc.php');
		}
        $reqfile = $CFG->dirroot."/enrol/mpay/version.php";
        require($reqfile);
        $clientversion = $plugin->version;
        
        if (SYSTEM_SSL == false)
        {
        	$ixr = new IXR_Client(SYSTEM_URL,false,80,false,$clientversion);
        }
        else
        {
        	$ixr = new IXR_ClientSSL(SYSTEM_URL,false,443,false,$clientversion);
        }
        if (!is_a($ixr,'IXR_Client') && !is_a($ixr,'IXR_ClientSSL'))
        {
            return false;
        }
        
        # Test if the system is ready for use
        # If the server doesn't respond within 10 sec, we assume it's not ready
        $ixr->timeout = 10;
        try
        {
            $ixr->query('proxy.serverready',time());
            $response = $ixr->getResponse();
            if ($response!=true)
            {
                return false;
            }
        }
        catch (Exception $ex)
        {
            return false;
        }
        $ixr->timeout = false;
        $this->ixr = $ixr;
        
        return true;
	}
	
	public function verifyTransaction($request)
	{
	    global $CFG;
	    
	    if ($request->status == -10)
	    {
	        return false; # This shouldn't be possible!!!! (Just a precaution)
	    }
	    
	    $question = array(
	                       'cmd'               => 'verifyTransaction',
	                       'user_id'           =>  $request->user_id,
	                       'course_id'         =>  $request->course_id,
	                       'status'            =>  $request->status,
	                       'websitecode'       =>  $CFG->enrol_mpay_websitecode,
	                       'transactiontype'   =>  $request->transactiontype,
                        );
        if ($this->ixr === null)
        {
            if ($this->init_xmlrpc_connection() == false)
            {
                return false;
            }
        }
        
		$this->ixr->query('transaction.verify',$question);
		$response = $this->ixr->getResponse();
		if ($response == false)
		{
		    return false;
		}
		else
		{
		    return true;
		}
	}
	
	public function getCurrentDiscounts()
	{
		global $CFG;
		
        if ($this->ixr === null)
        {
            if ($this->init_xmlrpc_connection() == false)
            {
                return false;
            }
        }
		
        $config = array(
        					'cmd'			=> 'getdiscounts',
        					'websitecode'	=> $CFG->enrol_mpay_websitecode,
        			);
        
        $this->ixr->query('config.getdiscounts',$config);
        
        $response = $this->ixr->getResponse();
        if ($response === false)
        {
        	return false;
        }
        return $response;
	}
	
	public function editDiscount(array $args)
	{
		global $CFG;
		
        if ($this->ixr === null)
        {
            if ($this->init_xmlrpc_connection() == false)
            {
                return false;
            }
        }
        
        if (intval($args['id']) <= 0)
        {
        	return false;
        }
        if ($args['percentage'] == 0 && $args['newprice'] == 0)
        {
        	return false;
        }
        
        $config = array_merge($args,array('cmd' => 'editdiscount','websitecode'=>$CFG->enrol_mpay_websitecode));
        $this->ixr->query('config.editdiscount',$config);
        
        $response = $this->ixr->getResponse();
        if ($response === false)
        {
        	return false;
        }
        return $response;
	}
	
	public function addDiscount(array $args)
	{
		global $CFG;
		
        if ($this->ixr === null)
        {
            if ($this->init_xmlrpc_connection() == false)
            {
                return false;
            }
        }
        
        if (isset($args['id']) && $args['id'] > 0)
        {
        	return false;
        }
        if ($args['percentage'] == 0 && $args['newprice'] == 0)
        {
        	return false;
        }
        
        $config = array_merge($args,array('cmd' => 'adddiscount','websitecode'=>$CFG->enrol_mpay_websitecode));
        $this->ixr->query('config.adddiscount',$config);
        
        $response = $this->ixr->getResponse();
        if ($response === false)
        {
        	return false;
        }
        return $response;
	}
}