<?php
/**
* @desc 	  MoodlePayments  - Pay for a course enrolment
* @since 	  1.8
* @version	  1.3
* @author	  Luuk Verhoeven [luuk@sebsoft.nl] / Sebastian Berm [sebastian@sebsoft.nl]
* @package    enrol/mpay
* @copyright  Sebsoft.nl
*/
//Setting for the enrolment
require_once('../../config.php');
require_once('forms.php');

$courseid   = required_param('courseid', PARAM_INT);
$instanceid = optional_param('id', 0, PARAM_INT); // instanceid

$course = $DB->get_record('course', array('id'=>$courseid), '*', MUST_EXIST);
$context = context_course::instance($course->id, MUST_EXIST);

require_login($course);
require_capability('enrol/mpay:config', $context);

$PAGE->set_url('/enrol/mpay/edit.php', array('courseid'=>$course->id, 'id'=>$instanceid));
$PAGE->set_pagelayout('admin');

$return = new moodle_url('/enrol/instances.php', array('id'=>$course->id));
if (!enrol_is_enabled('mpay')) {
    redirect($return);
}

$plugin = enrol_get_plugin('mpay');


if ($instances = $DB->get_records('enrol', array('courseid'=>$course->id, 'enrol'=>'mpay'), 'id ASC')) 
{
    $instance = array_shift($instances);
    if ($instances) 
    {
        // oh - we allow only one instance per course!!
        foreach ($instances as $del) 
        {
            $plugin->delete_instance($del);
        }
    }
}
else 
{
    require_capability('moodle/course:enrolconfig', $context);
    // no instance yet, we have to add new instance
    navigation_node::override_active_url(new moodle_url('/enrol/instances.php', array('id'=>$course->id)));
    $instance = new stdClass();
    $instance->id       = null;
    $instance->courseid = $course->id;
}

$mform = new enrol_mpay_edit_form(NULL, array($instance, $plugin, $context));

if ($mform->is_cancelled()) 
{
    redirect($return);
}
elseif ($data = $mform->get_data()) 
{
    if ($instance->id) 
    {
        $instance->status         	= 0;
        $instance->enrolperiod  	= $data->enrolperiod;
        $instance->name          	= $data->name;
        $instance->cost          	= $data->cost;
        $instance->currency             = $data->currency;
        $instance->roleid         	= $data->roleid;
        $instance->timemodified   	= time();
        $DB->update_record('enrol', $instance);
    }
    else 
    {
        $fields = array('status'=>0, 'name'=>$data->name, 'enrolperiod'=>$data->enrolperiod, 'roleid'=>$data->roleid,'cost'=> $data->cost,'currency'=>$data->currency);
        $plugin->add_instance($course, $fields);
    }
    redirect($return);
}

$PAGE->set_heading($course->fullname);
$PAGE->set_title(get_string('pluginname', 'enrol_mpay'));

echo $OUTPUT->header();
echo $OUTPUT->heading(get_string('pluginname', 'enrol_mpay'));
$mform->display();
echo $OUTPUT->footer();
