<?php  
/**
* @desc 	  MoodlePayments  - Pay for a course enrolment
* @since 	  1.8
* @version	  1.3
* @author	  Luuk Verhoeven [luuk@sebsoft.nl] / Sebastian Berm [sebastian@sebsoft.nl]
* @package    enrol/mpay
* @copyright  Sebsoft.nl
*/
/**
 * Listener for mpsup (Moodle Payments Status Updates) from mPay services
 * 
 * Every time we receive something, here, we want to verify it with mPay...
 * This will make sure we will actually get everything working the way it should....
 */
require_once ("../../config.php");
//require("enrol.php");
require_once (dirname(__FILE__) .'/class/mpsup_processor.php');
require_once (dirname(__FILE__) .'/class/mpay.class.php');
require_once (dirname(__FILE__) .'/basesettings.php');
require_once (dirname(__FILE__) .'../../../lib/enrollib.php');


global $DB;
/// Keep out casual intruders
if (empty($_POST) or !empty($_GET)) {
	print_error("Sorry, you can not use the script that way.");
}


$data = new stdClass();
$req = "";
foreach ($_POST as $key => $value)
{
	$value = stripslashes($value);
	$req .= "&$key=".urlencode($value);
	$data->$key = $value;
}


/**
 * We should at least get:
 * cmd <-- command from webservices to us!
 * user_id
 * course_id
 * amount (which is still in cents)
 * currency (defaults to EUR)
 * status <-- MOST IMPORTANT
 * transactiontype
 * txn_id <-- transactiontype-unique_id
 * 
 */
$data->timeupdated      = time();



/// get the user and course records

if (! $user = $DB->get_record("user", array("id"=> $data->user_id)) ) {
	email_mpay_error_to_admin("Not a valid user id", $data);
	echo "false|not a valid user id";
	die;
}

if (! $course = $DB->get_record("course", array("id"=> $data->course_id)) ) {
	email_mpay_error_to_admin("Not a valid course id", $data);
	echo "false|not a valid course id";
	die;
}
$enrolSettings  = Mpay::getEnrolSettings($course->id);

if (! $context = get_context_instance(CONTEXT_COURSE, $course->id)) {
	email_mpay_error_to_admin("Not a valid context id", $data);
	echo "false|not a valid context id";
	die;
}

# If we're still alive here, we should verify the action
$mpsup = new mpsupProcessor(); # Hmm, I should think of more logical names, shouldn't I?
if ($mpsup->verifyTransaction($data) == false)
{
	# Hmm, we've got a false for some reason...
	# Let's just mail the admin about that, shall we?
	$DB->insert_record("enrol_mpay", $data);
	email_mpay_error_to_admin("Received an invalid payment notification!! (Fake payment or server error?)", $data);
	echo "false|does not match verification procedure";
	die();
}

if ($data->status >= 2 && $data->status <= 5)
{
	# We should enrol the user, if that hasn't already been done
	if ($existing = $DB->get_record("enrol_mpay", array("txn_id" => $data->txn_id)))
	{
		// Make sure this transaction doesn't exist already (unless it should)
		if ($data->status >= 3)
		{
			# So status is 3, 4 or 5, which is all allowed to be 'not new'
			$existing->status = $data->status;
			$existing->timeupdated = $data->timeupdated;
			if ($DB->update_record("enrol_mpay",$existing))
			{
				echo "true|updated";
				exit;
			}
			else
			{
				echo "false|db error";
				exit;
			}
		}
		# Is this an actual error?
		//email_mpay_error_to_admin("Transaction $data->txn_id is being repeated!", $data);
		//echo "false|Transaction is being repeated!";
		echo "true|transaction is being repeated. Please confirm manually.";
		exit;
	}
	
	# If we're still here, we should allow this user to access the course, if the data checks out
	if (!$user = $DB->get_record('user', array('id' => $data->user_id)))
	{   // Check that user exists
		email_mpay_error_to_admin("User $data->user_id doesn't exist", $data);
		echo "false|user does not exist";
		die;
	}
	if (!$course = $DB->get_record('course', array('id' => $data->course_id)))
	{   // Check that course exists
		email_mpay_error_to_admin("Course $data->course_id doesn't exist", $data);;
		echo "false|course does not exist";
		die;
	}
	
	// Check that amount paid is the correct amount
	if ( (float)$enrolSettings->cost < 0 )
	{
		$cost = (float) $CFG->enrol_mpay_amount;
	} else {
		$cost = (float) $enrolSettings->cost ;
	}
	# We get amount back in cents, so we need cost as cents
	$cost = (float) ($cost * 100);
	if ($data->amount < $cost)
	{
		$cost = format_float($cost, 2);
		email_mpay_error_to_admin("Amount paid is not enough ($data->amount < $cost cents))", $data);
		echo "false|system reports the amount is not enough";
		die;
	}
	
	# If we're still alive now, we've passed all checks
	if (!$DB->insert_record("enrol_mpay", $data))
	{
		// Insert a transaction record - semi critical, we can continue!
		email_mpay_error_to_admin("Error while trying to insert valid transaction", $data);
	}

	$roleid			= $enrolSettings->roleid;
    $timestart 		= time();
	if(empty($enrolSettings->enrolperiod))
	{
		//50years
		$timeend   	= $timestart + (3600*24*365*50);
	}
	else 
	{
		$timeend   	= $timestart + $enrolSettings->enrolperiod;
	}
					   			
	//Setting courseid
	$result 			= $DB->get_record('enrol',array('enrol'=>'mpay','courseid'=>$course->id));
	if($result)
	{
		$instance->id 		= $result->id;
		$instance->courseid = $course->id;
		$instance->enrol	= 'mpay';
	}
	else 
	{
		echo "false|We have not found mpay enrol";
	}
	
	if (!Mpay::enrol_user($instance, $user->id, $roleid,$timestart,$timeend,ENROL_USER_ACTIVE))
	{
		email_mpay_error_to_admin("Error while trying to enrol ".fullname($user)." in '$course->fullname'", $data);
		echo "false|error while enrolling";
		die;
	} 
	else 
	{
		if ($users = get_users_by_capability($context, 'moodle/course:update', 'u.*', 'u.id ASC','', '', '', '', false, true)) 
		{
            $users = sort_by_roleassignment_authority($users, $context);
            $teacher = array_shift($users);
        } 
	
		if (!empty($CFG->enrol_mpay_mpay_mailstudents)) {
			$a->coursename = $course->fullname;
			$a->profileurl = "$CFG->wwwroot/user/view.php?id=$user->id";
			email_to_user($user, $teacher, get_string("enrolmentnew", 'enrol', $course->shortname),get_string('welcometocoursetext', 'enrol', $a));
		}
		if (!empty($CFG->enrol_mpay_mailteachers)) 
		{
			$a->course = $course->fullname;
			$a->user = fullname($user);
			if(!empty($teacher))
			{
			    email_to_user($teacher, $user, get_string("enrolmentnew", 'enrol', $course->shortname),get_string('enrolmentnewuser', 'enrol', $a));
			}
		}

		if (!empty($CFG->enrol_mpay_mailadmins)) {
			$a->course = $course->fullname;
			$a->user = fullname($user);
			$admins = get_admins();
			foreach ($admins as $admin) {
				email_to_user($admin, $user, get_string("enrolmentnew", 'enrol', $course->shortname),get_string('enrolmentnewuser', 'enrol', $a));
			}
		}
		echo "true|user enrolled";
		exit;
	}
}
else
{
	# Some kind of status update... Just process the update... k tnx bye...
	# (This is for the next version, so you also get notifies when you're paid by mPay)
	if ($existing = $DB->get_record("enrol_mpay", array("txn_id" => $data->txn_id)))
	{
		$existing->status = $data->status;
		$existing->timeupdated = $data->timeupdated;
		if ($DB->update_record("enrol_mpay",$existing))
		{
			echo "true|updated";
			exit;
		}
		else
		{
			echo "false|db error";
			exit;
		}
	}
}
if ($data->status == -3)
{
	echo "true|never saved here";
	exit;
}
// In some cases, like status 'requested transaction, but canceled', we may get here...
// Just echo true, to make sure, our system shuts up, and doesn't retry
echo "true|unable to find, not caring about it";
?>