<?php

/**
 * @desc 	  MoodlePayments  - Pay for a course enrolment
 * @since 	  1.8
 * @version	  1.3
 * @author	  Luuk Verhoeven [luuk@sebsoft.nl] / Sebastian Berm [sebastian@sebsoft.nl]
 * @package    enrol/mpay
 * @copyright  Sebsoft.nl
 */
require_once dirname(__FILE__) . '/class/mpay.class.php';
require_once(dirname(__FILE__) . '/basesettings.php');
require_once(dirname(__FILE__) . '/settingslib.php');

defined('MOODLE_INTERNAL') || die();

if ($ADMIN->fulltree) {
    global $CFG;
    //--- settings ------------------------------------------------------------------------------------------
    $settings->add(new admin_setting_heading('enrol_mpay_description', '', "<div ><b>"
            . get_string('general_settings', 'enrol_mpay') .
            "</b></div><br>"
            . get_string('description', 'enrol_mpay')
            . '<font>' . get_string('setting_enrol_websitecode', 'enrol_mpay') . '</font>'
    ));

    $setting = !empty($CFG->enrol_mpay_websitecode) ? $CFG->enrol_mpay_websitecode : '';
    $settings->add(new admin_setting_configtext('enrol_mpay_websitecode', get_string('websitecode', 'enrol_mpay'), get_string('websiteid', 'enrol_mpay'), $setting, PARAM_MULTILANG));

    $arrayCurrencies = get_string_manager()->get_list_of_currencies();
    $settings->add(new configselect_reload('enrol_mpay_currency', get_string('currency', 'enrol_mpay'), get_string('currency_desc', 'enrol_mpay'), 'EUR', $arrayCurrencies));

    $settings->add(new admin_setting_configtext('enrol_mpay_amount', get_string('amount', 'enrol_mpay'), get_string('amount_desc', 'enrol_mpay'), 10, PARAM_FLOAT));

    //websitecode
    $settings->add(new admin_setting_heading('enrol_mpay_couponcode', '', "<div><b>" . get_string('couponcodes', 'enrol_mpay') . "</b></div><br>" . get_string('how_does_couponcode_work', 'enrol_mpay')));

    //Coupon discount
    $optionsYesNo = array(1 => get_string('yes'), 0 => get_string('no'));

    $settings->add(new admin_setting_configselect('enrol_mpay_enable_couponcode', get_string('setting_enable_couponcode', 'enrol_mpay'), get_string('enable_couponcode', 'enrol_mpay'), 0, $optionsYesNo));

    //$CFG->wwwroot."/enrol/mpay/couponmanager.php
    $settings->add(new admin_setting_heading('enrol_mpay_couponcode_link', '', "<div><a style='text-decoration:underline;' href='" . $CFG->wwwroot . "/enrol/mpay/couponmanager.php'>" . get_string('click_link', 'enrol_mpay') . "</a> " . get_string('setting_coupon_percent', 'enrol_mpay') . "</div>"));

    //discount procent
    //$setting = !empty($CFG->enrol_mpay_coupon_percent) ? $CFG->enrol_mpay_coupon_percent : '';
    //$settings->add(new admin_setting_configtext('enrol_mpay_coupon_percent', get_string('setting_coupon_percent', 'enrol_mpay'), get_string('coupon_percent', 'enrol_mpay'), $setting, PARAM_MULTILANG));

    $settings->add(new admin_setting_heading('enrol_mpay_paymethods', '', "<div><b>" . get_string('paymentmethods', 'enrol_mpay') . "</b></div>"));

    //Paymentmethode Default
    $options = Mpay::getPaymentMethods(false);
    $settings->add(new admin_setting_configselect('enrol_mpay_default_payment_methode', get_string('setting_default_payment_method', 'enrol_mpay'), get_string('default_always_enabled', 'enrol_mpay'), '', $options));

    //$objects	= $CFG->enrol_mpay_payment_methode;
    //Setting profiles on or off
    foreach ($options as $option) {
        $settings->add(new admin_setting_configcheckbox('enrol_mpay_payment_methode_' . $option, get_string('enable') . ' (' . $option . ')', get_string('enabled', 'enrol_mpay'), ''));
    }
    $settings->add(new admin_setting_heading('enrol_mpay_vat', '', "<div><a style='text-decoration:underline;' href='" . $CFG->wwwroot . "/enrol/mpay/vatmanager.php'>" . get_string('click_link', 'enrol_mpay') . "</a> " . get_string('setting_vat_exceptions', 'enrol_mpay') . "</div>"));


    //adding the dev setting if is turnt on
    if (DEVMODE == true) {
        $settings->add(new admin_setting_heading('enrol_mpay_devmode', '', "<div><b>" . get_string('devmode', 'enrol_mpay') . "</b></div><br>" . get_string('devmode_desc', 'enrol_mpay')));

        $settings->add(new admin_setting_configcheckbox('enrol_mpay_payment_methode_demomode', get_string('setting_demo_mode', 'enrol_mpay'), get_string('enable_demo', 'enrol_mpay'), ''));
        $settings->add(new admin_setting_configcheckbox('enrol_mpay_sandbox', get_string('sandbox', 'enrol_mpay'), get_string('sandbox_desc', 'enrol_mpay'), ''));
    } else {
        $settings->add(new admin_setting_heading('enrol_mpay_devmode', '', "<div><b>" . get_string('devmode_disabled', 'enrol_mpay') . "</b></div><br>" . get_string('devmode_disabled_desc', 'enrol_mpay')));
    }

    //Informing
    $settings->add(new admin_setting_heading('enrol_mpay_informing', '', "<div ><b>"
            . get_string('informing', 'enrol_mpay') .
            "</b></div>"
    ));

    $settings->add(new admin_setting_configcheckbox('enrol_mpay_mailstudents', get_string('setting_mailstudents_info', 'enrol_mpay'), get_string('mailstudents', 'enrol_mpay'), ''));
    $settings->add(new admin_setting_configcheckbox('enrol_mpay_mailteachers', get_string('setting_mailteachers_info', 'enrol_mpay'), get_string('mailteachers', 'enrol_mpay'), ''));
    $settings->add(new admin_setting_configcheckbox('enrol_mpay_mailadmins', get_string('setting_mailadmins_info', 'enrol_mpay'), get_string('mailadmins', 'enrol_mpay'), ''));
}